@@ -12,12 +12,16 @@
  */
 
 #include <errno.h>
+#include <fcntl.h>
 #include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
+#include <sys/stat.h>
+#include <sys/types.h>
 #include <sys/wait.h>
+#include <unistd.h>
+
 
 #include <libgearman/gearman.h>
 
@@ -47,11 +51,13 @@ typedef struct
   bool suppress_input;
   bool prefix;
   bool background;
+  bool daemon;
   gearman_job_priority_t priority;
   int timeout;
   char **argv;
   gearman_task_st *task;
   char return_value;
+  char *pid_file;
 } gearman_args_st;
 
 /**
@@ -92,8 +98,8 @@ static void _worker(gearman_args_st *args);
 /**
  * Callback function when worker gets a job.
  */
-static void *_worker_cb(gearman_job_st *job, void *cb_arg, size_t *result_size,
-                        gearman_return_t *ret_ptr);
+static void *_worker_cb(gearman_job_st *job, void *context,
+                        size_t *result_size, gearman_return_t *ret_ptr);
 
 /**
  * Read workload chunk from a file descriptor and put into allocated memory.
@@ -106,10 +112,47 @@ static void _read_workload(int fd, char **workload, size_t *workload_offset,
  */
 static void usage(char *name);
 
+/*
+  Pid file functions.
+*/
+static bool _pid_write(const char *pid_file)
+{
+  FILE *f;
+
+  f= fopen(pid_file, "w");
+  if (f == NULL)
+  {
+    fprintf(stderr, "gearmand: Could not open pid file for writing: %s (%d)\n",
+            pid_file, errno);
+    return true;
+  }
+
+  fprintf(f, "%" PRId64 "\n", (int64_t)getpid());
+
+  if (fclose(f) == -1)
+  {
+    fprintf(stderr, "gearmand: Could not close the pid file: %s (%d)\n",
+            pid_file, errno);
+    return true;
+  }
+
+  return false;
+}
+
+static void _pid_delete(const char *pid_file)
+{
+  if (unlink(pid_file) == -1)
+  {
+    fprintf(stderr, "gearmand: Could not remove the pid file: %s (%d)\n",
+            pid_file, errno);
+  }
+}
+
 int main(int argc, char *argv[])
 {
   int c;
   gearman_args_st args;
+  bool close_stdio= false;
 
   memset(&args, 0, sizeof(gearman_args_st));
   args.priority= GEARMAN_JOB_PRIORITY_NORMAL;
@@ -118,9 +161,11 @@ int main(int argc, char *argv[])
   /* Allocate the maximum number of possible functions. */
   args.function= malloc(sizeof(char *) * (size_t)argc);
   if (args.function == NULL)
-    GEARMAN_ERROR("malloc:%d", errno)
+  {
+    GEARMAN_ERROR("malloc:%d", errno);
+  }
 
-  while ((c = getopt(argc, argv, "bc:f:h:HILnNp:Pst:u:w")) != -1)
+  while ((c = getopt(argc, argv, "bc:f:h:HILnNp:Pst:u:wi:d")) != -1)
   {
     switch(c)
     {
@@ -132,6 +177,10 @@ int main(int argc, char *argv[])
       args.count= (uint32_t)atoi(optarg);
       break;
 
+    case 'd':
+      args.daemon= true;
+      break;
+
     case 'f':
       args.function[args.function_count]= optarg;
       args.function_count++;
@@ -141,6 +190,10 @@ int main(int argc, char *argv[])
       args.host= optarg;
       break;
 
+    case 'i':
+      args.pid_file= strdup(optarg);
+      break;
+
     case 'I':
       args.priority= GEARMAN_JOB_PRIORITY_HIGH;
       break;
@@ -185,20 +238,86 @@ int main(int argc, char *argv[])
     case 'H':
     default:
       usage(argv[0]);
-      exit(1);
+      exit(0);
     }
   }
 
   args.argv= argv + optind;
 
   if (signal(SIGPIPE, SIG_IGN) == SIG_ERR)
-    GEARMAN_ERROR("signal:%d", errno)
+  {
+    GEARMAN_ERROR("signal:%d", errno);
+  }
+
+  if (args.daemon)
+  {
+    switch (fork())
+    {
+    case -1:
+      fprintf(stderr, "gearmand: fork:%d\n", errno);
+      return 1;
+
+    case 0:
+      break;
+
+    default:
+      return 0;
+    }
+
+    if (setsid() == -1)
+    {
+      fprintf(stderr, "gearmand: setsid:%d\n", errno);
+      return 1;
+    }
+
+    close_stdio= true;
+  }
+
+  if (close_stdio)
+  {
+    int fd;
+
+    /* If we can't remap stdio, it should not a fatal error. */
+    fd= open("/dev/null", O_RDWR, 0);
+
+    if (fd != -1)
+    {
+      if (dup2(fd, STDIN_FILENO) == -1)
+      {
+        fprintf(stderr, "gearmand: dup2:%d\n", errno);
+        return 1;
+      }
+
+      if (dup2(fd, STDOUT_FILENO) == -1)
+      {
+        fprintf(stderr, "gearmand: dup2:%d\n", errno);
+        return 1;
+      }
+
+      if (dup2(fd, STDERR_FILENO) == -1)
+      {
+        fprintf(stderr, "gearmand: dup2:%d\n", errno);
+        return 1;
+      }
+
+      close(fd);
+    }
+  }
+
+  if (args.pid_file != NULL && _pid_write(args.pid_file))
+    return 1;
 
   if (args.worker)
     _worker(&args);
   else
     _client(&args);
 
+  if (args.pid_file != NULL)
+  {
+    _pid_delete(args.pid_file);
+    free(args.pid_file);
+  }
+
   return args.return_value;
 }
 
@@ -212,14 +331,18 @@ void _client(gearman_args_st *args)
   uint32_t x;
 
   if (gearman_client_create(&client) == NULL)
-    GEARMAN_ERROR("Memory allocation failure on client creation")
+  {
+    GEARMAN_ERROR("Memory allocation failure on client creation");
+  }
 
   if (args->timeout >= 0)
     gearman_client_set_timeout(&client, args->timeout);
 
   ret= gearman_client_add_server(&client, args->host, args->port);
   if (ret != GEARMAN_SUCCESS)
-    GEARMAN_ERROR("gearman_client_add_server:%s", gearman_client_error(&client))
+  {
+    GEARMAN_ERROR("gearman_client_add_server:%s", gearman_client_error(&client));
+  }
 
   gearman_client_set_data_fn(&client, _client_data);
   gearman_client_set_warning_fn(&client, _client_warning);
@@ -230,7 +353,9 @@ void _client(gearman_args_st *args)
 
   args->task= malloc(sizeof(gearman_task_st) * args->function_count);
   if (args->task == NULL)
-    GEARMAN_ERROR("malloc:%d", errno)
+  {
+    GEARMAN_ERROR("malloc:%d", errno);
+  }
 
   if (args->argv[0] == NULL)
   {
@@ -240,7 +365,9 @@ void _client(gearman_args_st *args)
     {
       workload= malloc(GEARMAN_INITIAL_WORKLOAD_SIZE);
       if (workload == NULL)
-        GEARMAN_ERROR("malloc:%d", errno)
+      {
+        GEARMAN_ERROR("malloc:%d", errno);
+      }
 
       while (1)
       {
@@ -343,12 +470,16 @@ void _client_run(gearman_client_st *client, gearman_args_st *args,
       }
     }
     if (ret != GEARMAN_SUCCESS)
-      GEARMAN_ERROR("gearman_client_add_task:%s", gearman_client_error(client))
+    {
+      GEARMAN_ERROR("gearman_client_add_task:%s", gearman_client_error(client));
+    }
   }
 
   ret= gearman_client_run_tasks(client);
   if (ret != GEARMAN_SUCCESS)
-    GEARMAN_ERROR("gearman_client_run_tasks:%s", gearman_client_error(client))
+  {
+    GEARMAN_ERROR("gearman_client_run_tasks:%s", gearman_client_error(client));
+  }
 
   for (x= 0; x < args->function_count; x++)
     gearman_task_free(&(args->task[x]));
@@ -356,7 +487,7 @@ void _client_run(gearman_client_st *client, gearman_args_st *args,
 
 static gearman_return_t _client_data(gearman_task_st *task)
 {
-  gearman_args_st *args;
+  const gearman_args_st *args;
 
   args= gearman_task_context(task);
   if (args->prefix)
@@ -366,14 +497,16 @@ static gearman_return_t _client_data(gearman_task_st *task)
   }
 
   if (write(1, gearman_task_data(task), gearman_task_data_size(task)) == -1)
-    GEARMAN_ERROR("write:%d", errno)
+  {
+    GEARMAN_ERROR("write:%d", errno);
+  }
 
   return GEARMAN_SUCCESS;
 }
 
 static gearman_return_t _client_warning(gearman_task_st *task)
 {
-  gearman_args_st *args;
+  const gearman_args_st *args;
 
   args= gearman_task_context(task);
   if (args->prefix)
@@ -383,14 +516,16 @@ static gearman_return_t _client_warning(gearman_task_st *task)
   }
 
   if (write(2, gearman_task_data(task), gearman_task_data_size(task)) == -1)
-    GEARMAN_ERROR("write:%d", errno)
+  {
+    GEARMAN_ERROR("write:%d", errno);
+  }
 
   return GEARMAN_SUCCESS;
 }
 
 static gearman_return_t _client_status(gearman_task_st *task)
 {
-  gearman_args_st *args;
+  const gearman_args_st *args;
 
   args= gearman_task_context(task);
   if (args->prefix)
@@ -406,12 +541,15 @@ static gearman_return_t _client_fail(gearman_task_st *task)
 {
   gearman_args_st *args;
 
-  args= gearman_task_context(task);
+  args= (gearman_args_st *)gearman_task_context(task);
   if (args->prefix)
     fprintf(stderr, "%s: ", gearman_task_function_name(task));
 
   fprintf(stderr, "Job failed\n");
 
+  /**
+    @note Fix this so that we don't cast from const.
+  */
   args->return_value= 1;
   return GEARMAN_SUCCESS;
 }
@@ -421,16 +559,20 @@ void _worker(gearman_args_st *args)
   gearman_worker_st worker;
   gearman_return_t ret;
   uint32_t x;
-  
+
   if (gearman_worker_create(&worker) == NULL)
-    GEARMAN_ERROR("Memory allocation failure on client creation")
+  {
+    GEARMAN_ERROR("Memory allocation failure on client creation");
+  }
 
   if (args->timeout >= 0)
     gearman_worker_set_timeout(&worker, args->timeout);
 
   ret= gearman_worker_add_server(&worker, args->host, args->port);
   if (ret != GEARMAN_SUCCESS)
-    GEARMAN_ERROR("gearman_worker_add_server:%s", gearman_worker_error(&worker))
+  {
+    GEARMAN_ERROR("gearman_worker_add_server:%s", gearman_worker_error(&worker));
+  }
 
   for (x= 0; x < args->function_count; x++)
   {
@@ -438,8 +580,7 @@ void _worker(gearman_args_st *args)
                                      args);
     if (ret != GEARMAN_SUCCESS)
     {
-      GEARMAN_ERROR("gearman_worker_add_function:%s",
-                    gearman_worker_error(&worker))
+      GEARMAN_ERROR("gearman_worker_add_function:%s", gearman_worker_error(&worker));
     }
   }
 
@@ -447,7 +588,9 @@ void _worker(gearman_args_st *args)
   {
     ret= gearman_worker_work(&worker);
     if (ret != GEARMAN_SUCCESS)
-      GEARMAN_ERROR("gearman_worker_work:%s", gearman_worker_error(&worker))
+    {
+      GEARMAN_ERROR("gearman_worker_work:%s", gearman_worker_error(&worker));
+    }
 
     if (args->count > 0)
     {
@@ -460,10 +603,10 @@ void _worker(gearman_args_st *args)
   gearman_worker_free(&worker);
 }
 
-static void *_worker_cb(gearman_job_st *job, void *cb_arg, size_t *result_size,
-                        gearman_return_t *ret_ptr)
+static void *_worker_cb(gearman_job_st *job, void *context,
+                        size_t *result_size, gearman_return_t *ret_ptr)
 {
-  gearman_args_st *args= (gearman_args_st *)cb_arg;
+  gearman_args_st *args= (gearman_args_st *)context;
   int in_fds[2];
   int out_fds[2];
   char *result= NULL;
@@ -478,32 +621,40 @@ static void *_worker_cb(gearman_job_st *job, void *cb_arg, size_t *result_size,
     if (write(1, gearman_job_workload(job),
               gearman_job_workload_size(job)) == -1)
     {
-      GEARMAN_ERROR("write:%d", errno)
+      GEARMAN_ERROR("write:%d", errno);
     }
   }
   else
   {
     if (pipe(in_fds) == -1 || pipe(out_fds) == -1)
-      GEARMAN_ERROR("pipe:%d", errno)
+    {
+      GEARMAN_ERROR("pipe:%d", errno);
+    }
 
     switch (fork())
     {
     case -1:
-      GEARMAN_ERROR("fork:%d", errno)
+      GEARMAN_ERROR("fork:%d", errno);
 
     case 0:
       if (dup2(in_fds[0], 0) == -1)
-        GEARMAN_ERROR("dup2:%d", errno)
+      {
+        GEARMAN_ERROR("dup2:%d", errno);
+      }
 
       close(in_fds[1]);
 
       if (dup2(out_fds[1], 1) == -1)
-        GEARMAN_ERROR("dup2:%d", errno)
+      {
+        GEARMAN_ERROR("dup2:%d", errno);
+      }
 
       close(out_fds[0]);
 
       execvp(args->argv[0], args->argv);
-      GEARMAN_ERROR("execvp:%d", errno)
+      {
+        GEARMAN_ERROR("execvp:%d", errno);
+      }
 
     default:
       break;
@@ -517,21 +668,25 @@ static void *_worker_cb(gearman_job_st *job, void *cb_arg, size_t *result_size,
       if (write(in_fds[1], gearman_job_workload(job),
                 gearman_job_workload_size(job)) == -1)
       {
-        GEARMAN_ERROR("write:%d", errno)
+        GEARMAN_ERROR("write:%d", errno);
       }
     }
 
     close(in_fds[1]);
-    
+
     if (args->job_per_newline)
     {
       f= fdopen(out_fds[0], "r");
       if (f == NULL)
-        GEARMAN_ERROR("fdopen:%d", errno)
+      {
+        GEARMAN_ERROR("fdopen:%d", errno);
+      }
 
       result= malloc(GEARMAN_INITIAL_WORKLOAD_SIZE);
       if (result == NULL)
-        GEARMAN_ERROR("malloc:%d", errno)
+      {
+        GEARMAN_ERROR("malloc:%d", errno);
+      }
 
       while (1)
       {
@@ -558,7 +713,9 @@ static void *_worker_cb(gearman_job_st *job, void *cb_arg, size_t *result_size,
     }
 
     if (wait(&status) == -1)
-      GEARMAN_ERROR("wait:%d", errno)
+    {
+      GEARMAN_ERROR("wait:%d", errno);
+    }
 
     if (WEXITSTATUS(status) != 0)
     {
@@ -593,15 +750,21 @@ void _read_workload(int fd, char **workload, size_t *workload_offset,
 
       *workload= realloc(*workload, *workload_size);
       if(*workload == NULL)
-        GEARMAN_ERROR("realloc:%d", errno)
+      {
+        GEARMAN_ERROR("realloc:%d", errno);
+      }
     }
 
     read_ret= read(fd, *workload + *workload_offset,
                    *workload_size - *workload_offset);
     if (read_ret == -1)
-      GEARMAN_ERROR("execvp:%d", errno)
+    {
+      GEARMAN_ERROR("execvp:%d", errno);
+    }
     else if (read_ret == 0)
+    {
       break;
+    }
 
     *workload_offset += (size_t)read_ret;
   }
@@ -618,6 +781,7 @@ static void usage(char *name)
   printf("\t-H            - Print this help menu\n");
   printf("\t-p <port>     - Job server port\n");
   printf("\t-t <timeout>  - Timeout in milliseconds\n");
+  printf("\t-i <pidfile>  - Create a pidfile for the process\n");
 
   printf("\nClient options:\n");
   printf("\t-b            - Run jobs in the background\n");
