@@ -34,8 +34,9 @@ struct gearman_server_job_st
   struct {
     bool allocated;
   } options;
-  gearman_server_job_state_t state;
   gearman_job_priority_t priority;
+  bool ignore_job;
+  bool job_queued;
   uint32_t job_handle_key;
   uint32_t unique_key;
   uint32_t client_count;
