@@ -44,7 +44,7 @@ gearman_server_packet_create(gearman_server_thread_st *thread,
 
   if (server_packet == NULL)
   {
-    server_packet= malloc(sizeof(gearman_server_packet_st));
+    server_packet= (gearman_server_packet_st *)malloc(sizeof(gearman_server_packet_st));
     if (server_packet == NULL)
     {
       gearman_log_error(thread->gearman, "gearman_server_packet_create", "malloc");
