@@ -70,7 +70,7 @@ gearman_server_st *gearman_server_create(gearman_server_st *server)
 
   if (server == NULL)
   {
-    server= malloc(sizeof(gearman_server_st));
+    server= (gearman_server_st *)malloc(sizeof(gearman_server_st));
     if (server == NULL)
       return NULL;
 
@@ -353,8 +353,11 @@ gearman_return_t gearman_server_run_command(gearman_server_con_st *server_con,
     /* This may not be NULL terminated, so copy to make sure it is. */
     snprintf(option, GEARMAN_OPTION_SIZE, "%.*s",
              (uint32_t)(packet->arg_size[0]), (char *)(packet->arg[0]));
+
     if (!strcasecmp(option, "exceptions"))
-      server_con->options|= GEARMAN_SERVER_CON_EXCEPTIONS;
+    {
+      server_con->is_exceptions= true;
+    }
     else
     {
       return _server_error_packet(server_con, "unknown_option",
@@ -403,7 +406,9 @@ gearman_return_t gearman_server_run_command(gearman_server_con_st *server_con,
   case GEARMAN_COMMAND_PRE_SLEEP:
     server_job= gearman_server_job_peek(server_con);
     if (server_job == NULL)
-      server_con->options|= GEARMAN_SERVER_CON_SLEEPING;
+    {
+      server_con->is_sleeping= true;
+    }
     else
     {
       /* If there are jobs that could be run, queue a NOOP packet to wake the
@@ -419,9 +424,8 @@ gearman_return_t gearman_server_run_command(gearman_server_con_st *server_con,
 
   case GEARMAN_COMMAND_GRAB_JOB:
   case GEARMAN_COMMAND_GRAB_JOB_UNIQ:
-    server_con->options&=
-                  (gearman_server_con_options_t)~(GEARMAN_SERVER_CON_SLEEPING |
-                                                  GEARMAN_SERVER_CON_NOOP_SENT);
+    server_con->is_sleeping= false;
+    server_con->is_noop_sent= false;
 
     server_job= gearman_server_job_take(server_con);
     if (server_job == NULL)
@@ -540,8 +544,7 @@ gearman_return_t gearman_server_run_command(gearman_server_con_st *server_con,
       return ret;
 
     /* Remove from persistent queue if one exists. */
-    if (server_job->state & GEARMAN_SERVER_JOB_QUEUED &&
-        server->queue_done_fn != NULL)
+    if (server_job->job_queued && server->queue_done_fn != NULL)
     {
       ret= (*(server->queue_done_fn))(server, (void *)server->queue_context,
                                       server_job->unique,
@@ -600,8 +603,7 @@ gearman_return_t gearman_server_run_command(gearman_server_con_st *server_con,
     }
 
     /* Remove from persistent queue if one exists. */
-    if (server_job->state & GEARMAN_SERVER_JOB_QUEUED &&
-        server->queue_done_fn != NULL)
+    if (server_job->job_queued && server->queue_done_fn != NULL)
     {
       ret= (*(server->queue_done_fn))(server, (void *)server->queue_context,
                                       server_job->unique,
@@ -753,7 +755,7 @@ static gearman_return_t _server_run_text(gearman_server_con_st *server_con,
   gearman_server_function_st *function;
   gearman_server_packet_st *server_packet;
 
-  data= malloc(GEARMAN_TEXT_RESPONSE_SIZE);
+  data= (char *)malloc(GEARMAN_TEXT_RESPONSE_SIZE);
   if (data == NULL)
   {
     gearman_log_error(packet->universal, "_server_run_text", "malloc");
@@ -786,7 +788,7 @@ static gearman_return_t _server_run_text(gearman_server_con_st *server_con,
         /* Make sure we have at least GEARMAN_TEXT_RESPONSE_SIZE bytes. */
         if (size + GEARMAN_TEXT_RESPONSE_SIZE > total)
         {
-          new_data= realloc(data, total + GEARMAN_TEXT_RESPONSE_SIZE);
+          new_data= (char *)realloc(data, total + GEARMAN_TEXT_RESPONSE_SIZE);
           if (new_data == NULL)
           {
             (void) pthread_mutex_unlock(&thread->lock);
@@ -834,7 +836,7 @@ static gearman_return_t _server_run_text(gearman_server_con_st *server_con,
     {
       if (size + GEARMAN_TEXT_RESPONSE_SIZE > total)
       {
-        new_data= realloc(data, total + GEARMAN_TEXT_RESPONSE_SIZE);
+        new_data= (char *)realloc(data, total + GEARMAN_TEXT_RESPONSE_SIZE);
         if (new_data == NULL)
         {
           free(data);
@@ -959,8 +961,7 @@ _server_queue_work_data(gearman_server_job_st *server_job,
   for (server_client= server_job->client_list; server_client;
        server_client= server_client->job_next)
   {
-    if (command == GEARMAN_COMMAND_WORK_EXCEPTION &&
-        !(server_client->con->options & GEARMAN_SERVER_CON_EXCEPTIONS))
+    if (command == GEARMAN_COMMAND_WORK_EXCEPTION && !(server_client->con->is_exceptions))
     {
       continue;
     }
@@ -975,7 +976,7 @@ _server_queue_work_data(gearman_server_job_st *server_job,
       }
       else
       {
-        data= malloc(packet->data_size);
+        data= (uint8_t *)malloc(packet->data_size);
         if (data == NULL)
         {
           gearman_log_error(packet->universal, "_server_run_command", "malloc");
