@@ -54,7 +54,7 @@ gearman_server_worker_create(gearman_server_con_st *con,
     }
     else
     {
-      worker= malloc(sizeof(gearman_server_worker_st));
+      worker= (gearman_server_worker_st *)malloc(sizeof(gearman_server_worker_st));
       if (worker == NULL)
       {
         gearman_log_error(con->thread->gearman, "gearman_server_worker_create", "malloc");
