@@ -8,7 +8,7 @@
 
 /**
  * @file
- * @brief Server worker declarations
+ * @brief Worker Declarations
  */
 
 #ifndef __GEARMAN_SERVER_WORKER_H__
@@ -19,10 +19,31 @@ extern "C" {
 #endif
 
 /**
- * @addtogroup gearman_server_worker Server Worker Handling
+ * @ingroup gearman_server_worker
+ */
+struct gearman_server_worker_st
+{
+  struct {
+    bool allocated;
+  } options;
+  uint32_t job_count;
+  uint32_t timeout;
+  gearman_server_con_st *con;
+  gearman_server_worker_st *con_next;
+  gearman_server_worker_st *con_prev;
+  gearman_server_function_st *function;
+  gearman_server_worker_st *function_next;
+  gearman_server_worker_st *function_prev;
+  gearman_server_job_st *job_list;
+};
+
+/**
+ * @addtogroup gearman_server_worker Worker Declarations
  * @ingroup gearman_server
+ *
  * This is a low level interface for gearman server workers. This is used
  * internally by the server interface, so you probably want to look there first.
+ *
  * @{
  */
 
