@@ -33,6 +33,7 @@ typedef struct
 } worker_test_st;
 
 /* Prototypes */
+test_return_t echo_test(void *object);
 test_return_t queue_add(void *object);
 test_return_t queue_worker(void *object);
 
@@ -56,34 +57,79 @@ static void *counter_function(gearman_job_st *job __attribute__((unused)),
   return NULL;
 }
 
+test_return_t echo_test(void *object)
+{
+  gearman_client_st client, *client_ptr;
+  gearman_return_t rc;
+  size_t value_length;
+  const char *value= "This is my echo test";
+
+  (void)object;
+
+  value_length= strlen(value);
+
+  client_ptr= gearman_client_create(&client);
+  test_truth(client_ptr);
+
+  rc= gearman_client_echo(&client, (uint8_t *)value, value_length);
+
+  test_truth(rc == GEARMAN_SUCCESS);
+
+  gearman_client_free(&client);
+
+  return TEST_SUCCESS;
+}
+
+static test_return_t queue_clean(void *object)
+{
+  worker_test_st *test= (worker_test_st *)object;
+  gearman_worker_st *worker= &(test->worker);
+  uint32_t counter= 0;
+  gearman_return_t rc;
+
+  gearman_worker_set_timeout(worker, 200);
+  rc= gearman_worker_add_function(worker, "queue_test", 5, counter_function, &counter);
+  test_truth(rc == GEARMAN_SUCCESS);
+
+  // Clean out any jobs that might still be in the queue from failed tests.
+  while (1)
+  {
+    rc= gearman_worker_work(worker);
+    if (rc != GEARMAN_SUCCESS)
+      break;
+  }
+
+  return TEST_SUCCESS;
+}
+
 test_return_t queue_add(void *object)
 {
   worker_test_st *test= (worker_test_st *)object;
-  gearman_client_st client;
+  gearman_client_st client, *client_ptr;
   char job_handle[GEARMAN_JOB_HANDLE_SIZE];
   uint8_t *value= (uint8_t *)"background_test";
   size_t value_length= strlen("background_test");
+  gearman_return_t rc;
 
   test->run_worker= false;
 
-  if (gearman_client_create(&client) == NULL)
-    return TEST_FAILURE;
+  client_ptr= gearman_client_create(&client);
+  test_truth(client_ptr);
 
-  if (gearman_client_add_server(&client, NULL,
-                                WORKER_TEST_PORT) != GEARMAN_SUCCESS)
-  {
-    return TEST_FAILURE;
-  }
+  rc= gearman_client_add_server(&client, NULL, WORKER_TEST_PORT);
+  test_truth(rc == GEARMAN_SUCCESS);
 
-  if (gearman_client_do_background(&client, "queue_test", NULL, value,
-                                   value_length, job_handle) != GEARMAN_SUCCESS)
-  {
-    return TEST_FAILURE;
-  }
+  rc= gearman_client_echo(&client, (uint8_t *)value, value_length);
+  test_truth(rc == GEARMAN_SUCCESS);
+
+  rc= gearman_client_do_background(&client, "queue_test", NULL, value,
+                                   value_length, job_handle);
+  test_truth(rc == GEARMAN_SUCCESS);
 
   gearman_client_free(&client);
 
   test->run_worker= true;
+
   return TEST_SUCCESS;
 }
 
@@ -92,21 +138,18 @@ test_return_t queue_worker(void *object)
   worker_test_st *test= (worker_test_st *)object;
   gearman_worker_st *worker= &(test->worker);
   uint32_t counter= 0;
+  gearman_return_t rc;
 
-  if (!test->run_worker)
+  if (! test->run_worker)
     return TEST_FAILURE;
 
-  if (gearman_worker_add_function(worker, "queue_test", 5, counter_function,
-                                  &counter) != GEARMAN_SUCCESS)
-  {
-    return TEST_FAILURE;
-  }
+  rc= gearman_worker_add_function(worker, "queue_test", 5, counter_function, &counter);
+  test_truth(rc == GEARMAN_SUCCESS);
 
-  if (gearman_worker_work(worker) != GEARMAN_SUCCESS)
-    return TEST_FAILURE;
+  rc= gearman_worker_work(worker);
+  test_truth(rc == GEARMAN_SUCCESS);
 
-  if (counter == 0)
-    return TEST_FAILURE;
+  test_truth (counter != 0);
 
   return TEST_SUCCESS;
 }
@@ -150,14 +193,16 @@ void *world_create(test_return_t *error)
 test_return_t world_destroy(void *object)
 {
   worker_test_st *test= (worker_test_st *)object;
-  gearman_worker_free(&(test->worker));
   test_gearmand_stop(test->gearmand_pid);
+  gearman_worker_free(&(test->worker));
   free(test);
 
   return TEST_SUCCESS;
 }
 
 test_st tests[] ={
+  {"echo", 0, echo_test },
+  {"clean", 0, queue_clean },
   {"add", 0, queue_add },
   {"worker", 0, queue_worker },
   {0, 0, 0}
